@@ -27,7 +27,11 @@
 #include <tqapplication.h>
 
 #include "config.h"
+#if USE_BUILTIN_CHMLIB
 #include "chm_lib.h"
+#else
+#include <chm_lib.h>
+#endif
 #include "bitfiddle.h"
 #include "libchmfile.h"
 #include "libchmurlfactory.h"
@@ -527,13 +531,8 @@ bool LCHMFileImpl::ResolveObject(const TQString& fileName, chmUnitInfo *ui) cons
 size_t LCHMFileImpl::RetrieveObject(const chmUnitInfo *ui, unsigned char *buffer,
 								LONGUINT64 fileOffset, LONGINT64 bufferSize) const
 {
-#if USE_BUILTIN_CHMLIB
-	return ::chm_retrieve_object(m_chmFile, ui, buffer, 
-								 fileOffset, bufferSize);
-#else
 	return ::chm_retrieve_object(m_chmFile, const_cast<chmUnitInfo*>(ui),
 								 buffer, fileOffset, bufferSize);
-#endif
 }
 
 
@@ -865,7 +864,7 @@ TQCString LCHMFileImpl::convertSearchWord( const TQString & src )
 	};
 
 	if ( !m_textCodec )
-		return (TQCString) src.lower();
+		return src.lower().utf8();
 
 	TQCString dest = m_textCodec->fromUnicode (src);
 
@@ -997,7 +996,7 @@ bool LCHMFileImpl::parseFileAndFillArray( const TQString & file, QT34VECTOR< LCH
 		else if ( tagword == "/object" && in_object ) 
 		{
 			// a topic entry closed. Add a tree item
-			if ( entry.name )
+			if ( !entry.name.isEmpty() )
 			{
 				if ( !root_indent_offset_set )
 				{
